The license checks made at do_rootfs time are a fork bomb and extremely inefficient. We should remove the overhead of an exec call of "find" so many times in particular and use shell expansion instead or similar.
This is going to be a rewrite of that function. I'm part way through it now.
The feature could be covered by current QA performance testing.
Submitted to OE-Core: http://git.yoctoproject.org/cgit/cgit.cgi/poky-contrib/commit/?h=eflanagan/license_1.3&id=d4873d2c5a3c1b82e77bd7c64334372903a265e1
http://git.yoctoproject.org/cgit/cgit.cgi/poky/commit/?id=885e1f7e6886c783ae481afc7c08bac04843cae9
The build time for core-image-sato improved to 95 minutes (previous was 110 minutes)
(In reply to comment #5) > The build time for core-image-sato improved to 95 minutes (previous was 110 > minutes) do we know what the do_rootfs time was?
4 minutes 43 seconds for do_rootfs and do_build